from setuptools import setup

setup(name='GuessNumberLetter',
      version='0.3',
      description='Example Game of Object Oriented Programming in Python',
      long_description="Example Game of Object Oriented Programming in Python - Package that choose a number o letter random and you have to guess what is the correct number or letter.",
      url="https://github.com/giovanib02/Guess-number",
      author="Carlos Barillas",
      author_email="giovanib07@gmail.com",
      packages=['GuessNumberAndLetter'],
      zip_safe=False)